@@ -232,19 +232,30 @@ class Epoch(object):
         value will be used for the UTC->TAI conversion, and the internal leap
         seconds table will be bypassed.
 
+        It is also possible to provide a local time with the parameter
+        **local=True**. In such case, the method :meth:`utc2local()` is called
+        to compute the LocalTime-UTC difference. This implies that the
+        parameter **utc=True** is automatically set.
+
         .. note:: The UTC to TT correction is only carried out for dates after
            January 1st, 1972.
 
+        .. note:: Please bear in mind that, in order for the method
+           :meth:`utc2local()` to work, your operative system must be correctly
+           configured, with the right time and corresponding time zone.
+
         :param args: Either JDE, Epoch, date, datetime or year, month, day,
            hours, minutes, seconds values, by themselves or inside a tuple or
-           list
+           list.
         :type args: int, float, :py:class:`Epoch`, tuple, list, date,
            datetime
-        :param utc: Whether the provided epoch is a civil time (UTC)
+        :param utc: Whether the provided epoch is a civil time (UTC).
         :type utc: bool
         :param leap_seconds: This is the value to be used in the UTC->TAI
             conversion, instead of taking it from internal leap seconds table.
         :type leap_seconds: int, float
+        :param local: Whether the provided epoch is a local time.
+        :type utc: bool
 
         :returns: None.
         :rtype: None
@@ -290,6 +301,18 @@ class Epoch(object):
         >>> e.set(d)
         >>> print(e)
         2026871.8
+        >>> e = Epoch(JDE2000, utc=True)
+        >>> print(round((e - JDE2000) * DAY2SEC, 3))
+        64.184
+        >>> e = Epoch(2451545.0, utc=True)
+        >>> print(round((e - JDE2000) * DAY2SEC, 3))
+        64.184
+        >>> e = Epoch(JDE2000, local=True)
+        >>> print(round((e - JDE2000) * DAY2SEC - Epoch.utc2local(), 3))
+        64.184
+        >>> e = Epoch(JDE2000, local=True, leap_seconds=35.0)
+        >>> print(round((e - JDE2000) * DAY2SEC - Epoch.utc2local(), 3))
+        77.184
         """
 
         # Clean up the internal parameters
@@ -297,14 +320,15 @@ class Epoch(object):
         # If no arguments are given, return. Internal values are 0.0
         if len(args) == 0:
             return
-        # If we have only one argument, it can be a JDE or another Epoch object
+        # If we have only one argument, it can be a JDE, another Epoch object,
+        # a tuple with year, month, day, etc or a datetime object
         elif len(args) == 1:
             if isinstance(args[0], Epoch):
                 self._jde = args[0]._jde
-                return
+                year, month, day, hours, minutes, sec = self.get_full_date()
             elif isinstance(args[0], (int, float)):
                 self._jde = args[0]
-                return
+                year, month, day, hours, minutes, sec = self.get_full_date()
             elif isinstance(args[0], (tuple, list)):
                 year, month, day, hours, minutes, sec = \
                     self._check_values(*args[0])
@@ -333,16 +357,26 @@ class Epoch(object):
         day += hours / DAY2HOURS + minutes / DAY2MIN + sec / DAY2SEC
         # Handle the 'leap_seconds' argument, if pressent
         if "leap_seconds" in kwargs:
-            # Compute JDE
-            self._jde = self._compute_jde(year, month, day, utc2tt=False,
-                                          leap_seconds=kwargs["leap_seconds"])
+            if "local" in kwargs:
+                self._jde = self._compute_jde(
+                    year, month, day, utc2tt=False,
+                    leap_seconds=kwargs["leap_seconds"],
+                    local=kwargs["local"])
+            else:
+                self._jde = self._compute_jde(
+                    year, month, day, utc2tt=False,
+                    leap_seconds=kwargs["leap_seconds"])
         elif "utc" in kwargs:
             self._jde = self._compute_jde(year, month, day,
                                           utc2tt=kwargs["utc"])
+        elif "local" in kwargs:
+            self._jde = self._compute_jde(year, month, day,
+                                          local=kwargs["local"])
         else:
             self._jde = self._compute_jde(year, month, day, utc2tt=False)
 
-    def _compute_jde(self, y, m, d, utc2tt=True, leap_seconds=0.0):
+    def _compute_jde(self, y, m, d, utc2tt=False, leap_seconds=0.0,
+                     local=False):
         """Method to compute the Julian Ephemeris Day (JDE).
 
         .. note:: The UTC to TT correction is only carried out for dates after
@@ -356,8 +390,10 @@ class Epoch(object):
         :type d: float
         :param utc2tt: Whether correction UTC to TT is done automatically.
         :type utc2tt: bool
-        :param leap_seconds: Number of leap seconds to apply
+        :param leap_seconds: Number of leap seconds to apply.
         :type leap_seconds: float
+        :param local: Whether a local time has been provided.
+        :type utc2tt: bool
 
         :returns: Julian Ephemeris Day (JDE)
         :rtype: float
@@ -375,16 +411,20 @@ class Epoch(object):
                + iint(30.6001 * (m + 1.0)) + d + b - 1524.5)
         # If enabled, let's convert from UTC to TT, adding the needed seconds
         deltasec = 0.0
+        if local:
+            deltasec = Epoch.utc2local()
+            if not utc2tt and leap_seconds == 0.0:
+                utc2tt = True
         # In this case, UTC to TT correction is applied automatically
         if utc2tt:
             if y >= 1972:
-                deltasec = 32.184  # Difference between TT and TAI
+                deltasec += 32.184  # Difference between TT and TAI
                 deltasec += 10.0  # Difference between UTC and TAI in 1972
                 deltasec += Epoch.leap_seconds(y, m)
         else:  # Correction is NOT automatic
             if leap_seconds != 0.0:  # We apply provided leap seconds
                 if y >= 1972:
-                    deltasec = 32.184  # Difference between TT and TAI
+                    deltasec += 32.184  # Difference between TT and TAI
                     deltasec += 10.0  # Difference between UTC-TAI in 1972
                     deltasec += leap_seconds
         return jde + deltasec / DAY2SEC
@@ -447,7 +487,8 @@ class Epoch(object):
         if month == 2:
             if Epoch.is_leap(year):
                 limit_day = 29
-        if day > limit_day:
+        # Add '1' to 'limit_day' in order to allow for fractional days
+        if day >= limit_day + 1:
             raise ValueError("Invalid value for the input day")
 
         # We are ready to return the parameters
@@ -750,6 +791,30 @@ class Epoch(object):
                    - k * iint((mm + 9.0) / 12.0) + day - 30.0)
         return float(doy + frac)
 
+    def doy(self):
+        """This method returns the Day Of Year (DOY) for the current Epoch
+        object.
+
+        :returns: Day Of Year (DOY).
+        :rtype: float
+
+        >>> e = Epoch(1999, 1, 29)
+        >>> round(e.doy(), 1)
+        29.0
+        >>> e = Epoch(2017, 12, 31.7)
+        >>> round(e.doy(), 1)
+        365.7
+        >>> e = Epoch(2012, 3, 3.1)
+        >>> round(e.doy(), 1)
+        63.1
+        >>> e = Epoch(-400, 2, 29.9)
+        >>> round(e.doy(), 1)
+        60.9
+        """
+
+        y, m, d = self.get_date()
+        return Epoch.get_doy(y, m, d)
+
     @staticmethod
     def doy2date(year, doy):
         """This method takes a year and a Day Of Year values, and returns the
@@ -892,15 +957,29 @@ class Epoch(object):
     def utc2local():
         """Method to return the difference between UTC and local time.
 
-        By default, dates in this Epoch class are handled in Coordinated
-        Universal Time (UTC). This method provides you the seconds that you
-        have to add or subtract to UTC time to convert to your local time.
+        This method provides you the seconds that you have to add or subtract
+        to UTC time to convert to your local time. The correct way to apply
+        this method is according to the expression:
 
-        Please bear in mind that, in order for this method to work, you
-        operative system must be correctly configured, with the right time and
-        corresponding time zone.
+        utc2local() = LocalTime - UTC
 
-        :returns: Difference in seconds between local and UTC time.
+        Therefore, if for example you are located in a place whose
+        corresponding time zone is UTC+2, then this method will yield 7200
+        (seconds in two hours) and you must then apply this expression:
+
+        LocalTime = UTC + utclocal() = UTC + 7200
+
+        .. note:: Please bear in mind that, in order for this method to work,
+           your operative system must be correctly configured, with the right
+           time and corresponding time zone.
+
+        .. note:: Remember that class :py:class:`Epoch` internally stores time
+           as Terrestrial Time (TT), not UTC. In order to get the UTC time you
+           must use a method like :meth:`get_date()` or :meth:`get_full_date()`
+           and pass the parameter **utc=True**.
+
+        :returns: Difference in seconds between local and UTC time, in that
+            order.
         :rtype: float
         """
 
@@ -1208,10 +1287,21 @@ class Epoch(object):
         provide a non zero value to **leap_seconds** to apply a specific leap
         seconds value.
 
+        It is also possible to retrieve a local time with the parameter
+        **local=True**. In such case, the method :meth:`utc2local()` is called
+        to compute the LocalTime-UTC difference. This implies that the
+        parameter **utc=True** is automatically set.
+
+        .. note:: Please bear in mind that, in order for the method
+           :meth:`utc2local()` to work, your operative system must be correctly
+           configured, with the right time and corresponding time zone.
+
         :param utc: Whether the TT to UTC conversion mechanism will be enabled
         :type utc: bool
         :param leap_seconds: Optional value for leap seconds.
         :type leap_seconds: int, float
+        :param local: Whether the retrieved epoch is converted to local time.
+        :type utc: bool
 
         :returns: Year, month, day in a tuple
         :rtype: tuple
@@ -1258,6 +1348,8 @@ class Epoch(object):
         year = int(year)
         month = int(month)
 
+        # If enabled, let's convert from TT to UTC, subtracting needed seconds
+        deltasec = 0.0
         tt2utc = False
         if "utc" in kwargs:
             tt2utc = kwargs["utc"]
@@ -1266,22 +1358,24 @@ class Epoch(object):
             leap_seconds = kwargs["leap_seconds"]
         else:
             leap_seconds = 0.0
-        # If enabled, let's convert from TT to UTC, subtracting needed seconds
-        deltasec = 0.0
+        if "local" in kwargs:
+            deltasec = Epoch.utc2local()
+            if not tt2utc and leap_seconds == 0.0:
+                tt2utc = True
         # In this case, TT to UTC correction is applied automatically, but only
         # for dates after July 1st, 1972
         if tt2utc:
             if year > 1972 or (year == 1972 and month >= 7):
-                deltasec = 32.184  # Difference between TT and TAI
+                deltasec += 32.184  # Difference between TT and TAI
                 deltasec += 10.0  # Difference between UTC and TAI in 1972
                 deltasec += Epoch.leap_seconds(year, month)
         else:  # Correction is NOT automatic
             if leap_seconds != 0.0:  # We apply provided leap seconds
                 if year > 1972 or (year == 1972 and month >= 7):
-                    deltasec = 32.184  # Difference between TT and TAI
+                    deltasec += 32.184  # Difference between TT and TAI
                     deltasec += 10.0  # Difference between UTC-TAI in 1972
                     deltasec += leap_seconds
-
+        # Apply the correction if needed
         if deltasec != 0.0:
             doy = Epoch.get_doy(year, month, day)
             doy -= deltasec / DAY2SEC
@@ -1299,10 +1393,21 @@ class Epoch(object):
         provide a non zero value to **leap_seconds** to apply a specific leap
         seconds value.
 
+        It is also possible to retrieve a local time with the parameter
+        **local=True**. In such case, the method :meth:`utc2local()` is called
+        to compute the LocalTime-UTC difference. This implies that the
+        parameter **utc=True** is automatically set.
+
+        .. note:: Please bear in mind that, in order for the method
+           :meth:`utc2local()` to work, your operative system must be correctly
+           configured, with the right time and corresponding time zone.
+
         :param utc: Whether the TT to UTC conversion mechanism will be enabled
         :type utc: bool
         :param leap_seconds: Optional value for leap seconds.
         :type leap_seconds: int, float
+        :param local: Whether the retrieved epoch is converted to local time.
+        :type utc: bool
 
         :returns: Year, month, day, hours, minutes, seconds in a tuple
         :rtype: tuple
@@ -1675,9 +1780,9 @@ class Epoch(object):
             "Sunrise equation" of the Wikipedia at:
             https://en.wikipedia.org/wiki/Sunrise_equation
 
-        .. note:: This algorithm is only valid within the artic and antartic
-            circles (+/- 66d 33'). Outside that range this method returns
-            a ValueError exception
+        .. note:: This algorithm is only valid outside the artic and antartic
+            circles (+/- 66d 33'). For latitudes higher than +66d 33' and
+            smaller than -66d 33' this method returns a ValueError exception
 
         .. note:: The results are given in UTC time.
 
@@ -2091,6 +2196,9 @@ def main():
     # Get the Day Of Year corresponding to a given date
     print_me("Day Of Year (DOY) of 1978/11/14", Epoch.get_doy(1978, 11, 14))
     print_me("Day Of Year (DOY) of -400/2/29.9", Epoch.get_doy(-400, 2, 29.9))
+    # As before, but using the contents of the Epoch object
+    e = Epoch(2017, 12, 31.7)
+    print_me("Day Of Year (DOY) of 2017/12/31.7", round(e.doy(), 1))
 
     print("")
 
