@@ -527,7 +527,7 @@ class Sun(object):
                                                       + y * 0.00074))))
             elif target == "winter":
                 jde0 = (1721414.39987
-                        + y * (363242.88257 + y * (-0.00769
+                        + y * (365242.88257 + y * (-0.00769
                                                    + y * (-0.00933
                                                           - y * 0.00006))))
         elif (year >= 1000) and (year <= 3000):
@@ -573,7 +573,7 @@ class Sun(object):
         :type epoch: :py:class:`Epoch`
 
         :returns: Difference between apparent and mean time, as a tuple, in
-            minutes and seconds of time
+            minutes (int) and seconds (float) of time
         :rtype: tuple
         :raises: TypeError if input values are of wrong type.
 
@@ -610,8 +610,8 @@ class Sun(object):
         e = l0() - 0.0057183 - alpha + deltapsi * cos(epsilon.rad())
         e *= 4.0
         # Extract seconds
-        s = (abs(e) % 1) * 60.0
-        m = int(e)
+        s = (abs(e()) % 1) * 60.0
+        m = int(e())
         return m, s
 
     @staticmethod
